==> dojo-1.9.4.tgz: package/cldr/nls/el/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πε",
		"Πα",
		"Σα"
	],
	"months-format-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Ημέρα εβδομάδας",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, d/M/y",
	"dateFormatItem-MMMEd": "E, d MMM",
	"eraNarrow": [
		"π.Χ.",
		"μ.Χ."
	],
	"dateFormatItem-yMM": "MM/y",
	"days-format-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πε",
		"Πα",
		"Σα"
	],
	"dateFormat-long": "d MMMM y",
	"months-format-wide": [
		"Ιανουαρίου",
		"Φεβρουαρίου",
		"Μαρτίου",
		"Απριλίου",
		"Μαΐου",
		"Ιουνίου",
		"Ιουλίου",
		"Αυγούστου",
		"Σεπτεμβρίου",
		"Οκτωβρίου",
		"Νοεμβρίου",
		"Δεκεμβρίου"
	],
	"dateTimeFormat-medium": "{1} - {0}",
	"dayPeriods-format-wide-pm": "μ.μ.",
	"dateFormat-full": "EEEE, d MMMM y",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d/M/y",
	"field-era": "Περίοδος",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"Ιανουάριος",
		"Φεβρουάριος",
		"Μάρτιος",
		"Απρίλιος",
		"Μάιος",
		"Ιούνιος",
		"Ιούλιος",
		"Αύγουστος",
		"Σεπτέμβριος",
		"Οκτώβριος",
		"Νοέμβριος",
		"Δεκέμβριος"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "Έτος",
	"dateFormatItem-yMMM": "LLL y",
	"field-hour": "Ώρα",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαϊ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "Σήμερα",
	"field-day-relative+1": "Αύριο",
	"field-day-relative+2": "Μεθαύριο",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Ιαν",
		"Φεβ",
		"Μάρ",
		"Απρ",
		"Μάι",
		"Ιούν",
		"Ιούλ",
		"Αύγ",
		"Σεπ",
		"Οκτ",
		"Νοέ",
		"Δεκ"
	],
	"quarters-format-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"quarters-standAlone-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "h:mm:ss a",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"eraAbbr": [
		"π.Χ.",
		"μ.Χ."
	],
	"field-minute": "Λεπτό",
	"field-dayperiod": "π.μ./μ.μ.",
	"days-standAlone-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "Χτες",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} - {0}",
	"field-day-relative+-2": "Προχτές",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} - {0}",
	"dateFormatItem-yMMMM": "LLLL y",
	"field-day": "Ημέρα",
	"days-format-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"field-zone": "Ζώνη",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-year-relative+-1": "Προηγούμενο έτος",
	"field-month-relative+-1": "Προηγούμενος μήνας",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"eraNames": [
		"π.Χ.",
		"μ.Χ."
	],
	"days-format-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"days-standAlone-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Μήνας",
	"dateFormatItem-HHmm": "HH:mm",
	"dayPeriods-format-wide-am": "π.μ.",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-MMMMdd": "dd MMMM",
	"dateFormat-short": "d/M/yy",
	"field-second": "Δευτερόλεπτο",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-month-relative+0": "Τρέχων μήνας",
	"field-month-relative+1": "Επόμενος μήνας",
	"dateFormatItem-Ed": "E d",
	"field-week": "Εβδομάδα",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "Φέτος",
	"field-week-relative+-1": "Προηγούμενη εβδομάδα",
	"field-year-relative+1": "Επόμενο έτος",
	"dateFormatItem-mmss": "mm:ss",
	"dateTimeFormat-short": "{1} - {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-week-relative+0": "Αυτήν την εβδομάδα",
	"field-week-relative+1": "Επόμενη εβδομάδα"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/el/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"months-format-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-second-relative+0": "τώρα",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Ημέρα εβδομάδας",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, d/M/y",
	"field-wed-relative+0": "αυτήν την Τετάρτη",
	"field-wed-relative+1": "επόμενη Τετάρτη",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"eraNarrow": [
		"π.Χ.",
		"μ.Χ."
	],
	"field-tue-relative+-1": "προηγούμενη Τρίτη",
	"days-format-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "προηγούμενη Παρασκευή",
	"field-wed-relative+-1": "προηγούμενη Τετάρτη",
	"months-format-wide": [
		"Ιανουαρίου",
		"Φεβρουαρίου",
		"Μαρτίου",
		"Απριλίου",
		"Μαΐου",
		"Ιουνίου",
		"Ιουλίου",
		"Αυγούστου",
		"Σεπτεμβρίου",
		"Οκτωβρίου",
		"Νοεμβρίου",
		"Δεκεμβρίου"
	],
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "μ.μ.",
	"dateFormat-full": "EEEE, d MMMM y",
	"field-thu-relative+-1": "επόμενη Πέμπτη",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d/M/y",
	"field-era": "Περίοδος",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"Ιανουάριος",
		"Φεβρουάριος",
		"Μάρτιος",
		"Απρίλιος",
		"Μάιος",
		"Ιούνιος",
		"Ιούλιος",
		"Αύγουστος",
		"Σεπτέμβριος",
		"Οκτώβριος",
		"Νοέμβριος",
		"Δεκέμβριος"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "Έτος",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "Ώρα",
	"months-format-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαΐ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"field-sat-relative+0": "αυτό το Σάββατο",
	"field-sat-relative+1": "επόμενο Σάββατο",
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "σήμερα",
	"field-thu-relative+0": "αυτήν την Πέμπτη",
	"field-day-relative+1": "αύριο",
	"field-thu-relative+1": "επόμενη Πέμπτη",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "μεθαύριο",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Ιαν",
		"Φεβ",
		"Μάρ",
		"Απρ",
		"Μάι",
		"Ιούν",
		"Ιούλ",
		"Αύγ",
		"Σεπ",
		"Οκτ",
		"Νοέ",
		"Δεκ"
	],
	"quarters-format-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"quarters-standAlone-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "h:mm:ss a",
	"field-sun-relative+0": "αυτήν την Κυριακή",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "επόμενη Κυριακή",
	"quarters-standAlone-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"eraAbbr": [
		"π.Χ.",
		"μ.Χ."
	],
	"field-minute": "Λεπτό",
	"field-dayperiod": "π.μ./μ.μ.",
	"days-standAlone-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "χθες",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} - {0}",
	"field-day-relative+-2": "προχθές",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} - {0}",
	"field-fri-relative+0": "αυτήν την Παρασκευή",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "επόμενη Παρασκευή",
	"field-day": "Ημέρα",
	"days-format-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"field-zone": "Ζώνη ώρας",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-year-relative+-1": "προηγούμενο έτος",
	"field-month-relative+-1": "προηγούμενος μήνας",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"eraNames": [
		"προ Χριστού",
		"μετά Χριστόν"
	],
	"days-format-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"days-standAlone-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Μήνας",
	"dateFormatItem-HHmm": "HH:mm",
	"field-tue-relative+0": "αυτήν την Τρίτη",
	"field-tue-relative+1": "επόμενη Τρίτη",
	"dayPeriods-format-wide-am": "π.μ.",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "αυτήν τη Δευτέρα",
	"field-mon-relative+1": "επόμενη Δευτέρα",
	"dateFormat-short": "d/M/yy",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Δευτερόλεπτο",
	"field-sat-relative+-1": "προηγούμενο Σάββατο",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-sun-relative+-1": "προηγούμενη Κυριακή",
	"field-month-relative+0": "τρέχων μήνας",
	"field-month-relative+1": "επόμενος μήνας",
	"dateFormatItem-Ed": "E d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Εβδομάδα",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "φέτος",
	"field-week-relative+-1": "προηγούμενη εβδομάδα",
	"field-year-relative+1": "επόμενο έτος",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "προηγούμενη Δευτέρα",
	"field-week-relative+0": "αυτήν την εβδομάδα",
	"field-week-relative+1": "επόμενη εβδομάδα"
}
//end v1.x content
);
